
/*
 * -- Internal Use Only --
 *
 * These functions maintain the registry of classes. While a class
 * can be individually added to many interpreters, some information
 * like the type identifier is stored globally, because the class's
 * information structure is only present once in memory.
 *
 * The registry is held in the interpreter in the "TclObj_ClassInfo"
 * array. Two entries are made for each entry, one for the class's
 * name, and one for its identifier. Both array elements have as
 * value the memory address of the information structure.
 *
 * TclObj_RegisterClass() registers a new class with the interpreter,
 * initializing its data structures if necessary.
 *
 * TclObj_GetClassInfo() return the information structure for the
 * class. You can search for its identifier or its type name.
 *
 * $Id: register.h,v 1.3 1997/01/09 16:18:40 fp Exp $
 */

#ifndef __TCLOBJ_REGISTER_H__
#define __TCLOBJ_REGISTER_H__

#include <tcl.h>
#include "tclobj.h"

unsigned long		TclObj_RegisterIdentifier(Tcl_Interp *,
						  const char *);

unsigned long		TclObj_RegisterClass	(Tcl_Interp *,
						 TclObj_Info *);

TclObj_Info *		TclObj_GetClassInfo	(Tcl_Interp *,
						 unsigned long);

TclObj_Info *		TclObj_GetClassInfo	(Tcl_Interp *,
						 const char *);

unsigned long		TclObj_GetIdentifier	(Tcl_Interp *,
						 const char *);

#endif
