/*
 * Signature trees
 *
 * $Id: signature.h,v 1.2 1996/11/28 15:12:13 fp Exp $
 */

#ifndef __TCLOBJ_SIGNATURE_H__
#define __TCLOBJ_SIGNATURE_H__

#include <tcl.h>
#include "tclobj.h"

/*
 * special kinds of arguments and natively supported arguments
 */

#define TCL_OBJECT_ARGTYPE_VARARG	2
#define TCL_OBJECT_ARGTYPE_STRING	16
#define TCL_OBJECT_ARGTYPE_BOOL		32
#define TCL_OBJECT_ARGTYPE_DOUBLE	33
#define TCL_OBJECT_ARGTYPE_INT		34
#define TCL_OBJECT_ARGTYPE_UINT		35
#define TCL_OBJECT_ARGTYPE_LONG		36
#define TCL_OBJECT_ARGTYPE_ULONG	37
#define TCL_OBJECT_ARGTYPE_PTR		38

/*
 * Precompiled binary tree of member function signatures and their args
 */

typedef struct _TclObj_Argtree {
  unsigned long ident;			/* identifier of parameter       */
  const TclObj_Comtab *entry;		/* the command table entry       */
  const TclObj_Info *provider;		/* class that provides the func  */
  struct _TclObj_Argtree *next, *down;
} TclObj_Argtree;

typedef struct _TclObj_Signature {
  char *name;				/* name of function              */
  TclObj_Argtree *argtree;		/* the overloaded arg lists      */
  struct _TclObj_Signature *left, *right;
} TclObj_Signature;


unsigned long		TclObj_GetClassIdent	(Tcl_Interp *,
						 const char *);

TclObj_Signature *	TclObj_BuildSigtree	(Tcl_Interp *,
						 TclObj_Signature *,
						 const TclObj_Info *,
						 int *, int);

const TclObj_Argtree *	TclObj_SearchSignature	(Tcl_Interp *,
						 const TclObj_Info *,
						 const char *,
						 int, char *[],
						 int *);

int			TclObj_DumpMemberNames	(Tcl_Interp *,
						 const TclObj_Info *,
						 const char *,
						 int *);

int			TclObj_DumpSignatures	(Tcl_Interp *,
						 const TclObj_Info *,
						 const char *,
						 int *);

#endif

